;
;==========================================================================
;
; FILE: ufcenteradj.pro
;
; USAGE:  result = UFcenteradj(ufbuf, field)
;         ARGUMENTS  ufbuf  Buffer of UF words for a dwell of radar data
;                    field  Logical number of the data field
;
; ABSTRACT: Return the adjustment to the center of the first range gate
;           in units of meters, for the Nth data field
;
; AUTHOR:  I. Jeff Caylor
;          Science Systems and Applications, Inc.
;          5900 Princess Garden Parkway, Suite 300
;          Lanham, MD  20706
;
;     at:  NASA Goddard Space Flight Center
;          Code 912
;          Greenbelt, MD 20771
;          Voice: (301) 286-3767
;          Fax:   (301) 286-1762
;          Email: jeff.caylor@gsfc.nasa.gov
;
; CREATED: 7 April 1995
;
; MODIFIED:
;
;==========================================================================
;

;
; Return the range adjustment to the center of the first gate in meters
; for the Nth field
;
FUNCTION UFcenteradj, dwell, n
  d = UFfieldhdr(dwell, n)
  IF (d EQ -1) THEN  BEGIN
    RETURN, -1
  ENDIF
  RETURN, float(dwell(d + 3))
END
