;
;==========================================================================
;
; FILE: uftxpol.pro
;
; USAGE:  result = UFtxpol(ufbuf, field)
;         ARGUMENTS  ufbuf  Buffer of UF words for a dwell of radar data
;                    field  Logical number of the data field
;
; ABSTRACT: Return the polarization of the transmitted pulse for the Nth
;           data field in the buffer
;           Possible values are:
;             0  Horizontal    1  Vertical
;             2  Circular      3  Elliptical
;
; AUTHOR:  I. Jeff Caylor
;          Science Systems and Applications, Inc.
;          5900 Princess Garden Parkway, Suite 300
;          Lanham, MD  20706
;
;     at:  NASA Goddard Space Flight Center
;          Code 912
;          Greenbelt, MD 20771
;          Voice: (301) 286-3767
;          Fax:   (301) 286-1762
;          Email: jeff.caylor@gsfc.nasa.gov
;
; CREATED: 7 April 1995
;
; MODIFIED:
;
;==========================================================================
;

;
; Return the transmitted polarization for the Nth field
; Error = -1
;
FUNCTION UFtxpol, dwell, n
  d = UFfieldhdr(dwell, n)
  IF (d EQ -1) THEN  BEGIN
    RETURN, -1
  ENDIF
  RETURN, dwell(d + 10)
END
