;
;==========================================================================
;
; FILE: dwell_demo.pro
;
; USAGE: dwell_demo, filename
;        ARGUMENTS    filename   Name of UF disk file
;
; ABSTRACT:  Demonstration program to read two UF fields dwell by dwell
;
; AUTHOR:  I. Jeff Caylor
;          Science Systems and Applications, Inc.
;          5900 Princess Garden Parkway, Suite 300
;          Lanham, MD  20706
;
;     at:  NASA Goddard Space Flight Center
;          Code 912
;          Greenbelt, MD 20771
;          Voice: (301) 286-3767
;          Fax:   (301) 286-1762
;          Email: jeff.caylor@gsfc.nasa.gov
;
; CREATED: 15 August 1995
;
; MODIFIED:
;
;==========================================================================
;
PRO dwell_demo, filename
  PRINT, 'Reading file: ', filename
  OPENR, infile, filename, /GET_LUN
;
; ZN = Nadir original dBZ      VN = Nadir corrected Doppler
;
  fieldname = ['ZN', 'VN']
;
  maxgates = 512
  nfields = SIZE(fieldname)
  nfields = nfields(1)
  dwell = FLTARR(nfields, maxgates)
;
  WHILE (EOF(infile) NE 1)  DO  BEGIN
    UF_read_dwell, infile, ufbuf, /RDSS
    ;
    ; Extract field data from the UF buffer and trim the array
    ;
    FOR n = 0, nfields - 1 DO BEGIN
      UFnameddata, ufbuf, fieldname(n), data, ngates, ERROR = status
      dwell(n, 0 : ngates - 1) = data
    ENDFOR
    dwell = dwell(*, 0 : ngates - 1)
;
    print, UFstrtime(ufbuf), UFdwell(ufbuf), UFedop_ins_altitude(ufbuf), $
           UFedop_ins_latitude(ufbuf), UFedop_ins_longitude(ufbuf), ngates
    ;
    ; DO PROCESSING ON THE DWELL HERE
    ;
  ENDWHILE
  CLOSE, infile
  FREE_lun, infile
END
