;
;==========================================================================
;
; FILE: ufedop_instr_time.pro
;
; USAGE:  result = UFedop_instr_time(ufbuf)
;         ARGUMENT  ufbuf   Buffer of UF words for a dwell of radar data
;
; ABSTRACT: Return the EDOP system time (from the E-6 controller) as decimal
;           hours from the EDOP Local Use header
;
; AUTHOR:  I. Jeff Caylor
;          Science Systems and Applications, Inc.
;          5900 Princess Garden Parkway, Suite 300
;          Lanham, MD  20706
;
;     at:  NASA Goddard Space Flight Center
;          Code 912
;          Greenbelt, MD 20771
;          Voice: (301) 286-3767
;          Fax:   (301) 286-1762
;          Email: jeff.caylor@gsfc.nasa.gov
;
; CREATED: 7 April 1995
;
; MODIFIED:
;
;==========================================================================
;

;
; Return the current UF time in decimal hours
;
FUNCTION UFedop_instr_time, dwell
  i = UFedop_instrument(dwell)
  hour = float(dwell(i + 23))
  hour = hour + float(dwell(i + 24)) / 60.0
  hour = hour + float(dwell(i + 25)) / 3600.0
  RETURN, hour
END
