;
;==========================================================================
;
; FILE: ufstrtime.pro
;
; USAGE:  result = UFstrtime(ufbuf)
;         ARGUMENT  ufbuf  Buffer of UF words for a dwell of radar data
;
; ABSTRACT: Return the time of the current UF dwell from the Mandatory
;           header as an ASCII string
;           For EDOP this is the INS time
;
; AUTHOR:  I. Jeff Caylor
;          Science Systems and Applications, Inc.
;          5900 Princess Garden Parkway, Suite 300
;          Lanham, MD  20706
;
;     at:  NASA Goddard Space Flight Center
;          Code 912
;          Greenbelt, MD 20771
;          Voice: (301) 286-3767
;          Fax:   (301) 286-1762
;          Email: jeff.caylor@gsfc.nasa.gov
;
; CREATED: 7 April 1995
;
; MODIFIED: 5 April 1996 - IJC
;           Fixed bug that appended an extra "T" to a "UT" time zone
;
;==========================================================================
;

;
; Return the current UF time as a 12 character ASCII string:  hh:mm:ss ZZZ
;
FUNCTION UFstrtime, dwell
  tzone = UFtimezone(dwell)
  IF tzone EQ 'UT' THEN tzone = 'U'
  RETURN, STRING(FORMAT='(I2.2, ":", I2.2, ":", I2.2, A3, "T")', dwell(29), $
                 dwell(30), dwell(31), tzone)
END
