;
;==========================================================================
;
; FILE: mirvel_demo.pro
;
; USAGE:  mirvel_demo, filename, dgate, /TIME
;         ARGUMENTS:  filename   Name of the UF disk file
;                     dgate      Gate to plot above and below the surface echo
;                     /TIME      Use time for x-axis, otherwise dwell number
;
; ABSTRACT:  Demonstration program to read an EDOP UF file and plot the 
;            nadir Doppler velocity above and below the surface echo
;
; AUTHOR:  I. Jeff Caylor
;          Science Systems and Applications, Inc.
;          5900 Princess Garden Parkway, Suite 300
;          Lanham, MD  20706
;
;     at:  NASA Goddard Space Flight Center
;          Code 912
;          Greenbelt, MD 20771
;          Voice: (301) 286-3767
;          Fax:   (301) 286-1762
;          Email: jeff.caylor@gsfc.nasa.gov
;
; CREATED: 18 October 1995
;
; MODIFIED:
;
;==========================================================================
;
PRO mirvel_demo, filename, dgate, TIME=time
  PRINT, 'Reading file: ', filename
  OPENR, infile, filename, /GET_LUN
;
  vel1 = FLTARR(1000)        ; Doppler ABOVE the surface echo
  vel2 = FLTARR(1000)        ; Doppler BELOW the surface echo
  field = 'DN'               ; Uncorrected radial Doppler velocity
  xcoord = FLTARR(1000)
  IF NOT KEYWORD_SET(dgate) THEN dgate = 0
  ;
  ; Load data from disk
  ;
  dwell = 0
  WHILE (EOF(infile) NE 1)  DO  BEGIN
    UF_read_dwell, infile, ufbuf, /RDSS
    UFnameddata, ufbuf, field, radial, ngates, ERROR = status
    nsurfgate = UF_nadir_sgate(ufbuf, 1)  ; Change this line for FORWARD fields
    vel1(dwell) = radial(nsurfgate - dgate)
    vel2(dwell) = radial(nsurfgate + dgate)
    IF KEYWORD_SET(time) THEN $
      xcoord(dwell) = UFtime(ufbuf)  $
    ELSE  $
      xcoord(dwell) = FLOAT(UFedop_dwell(ufbuf))
    PRINT, 'Record: ', UFdwell(ufbuf), '  ', UFstrtime(ufbuf)
    dwell = dwell + 1
    radial = 0
  ENDWHILE
  CLOSE, infile
  FREE_LUN, infile
  ;
  ; Resize arrays
  ;
  vel1 = vel1(0 : dwell - 1)
  vel2 = vel2(0 : dwell - 1)
  xcoord = xcoord(0 : dwell - 1)
  ;
  ; Autoscale the vertical axis
  ;  
  IF MAX(vel1) LT -MIN(vel2) THEN range = -MIN(vel2) ELSE range = MAX(vel1)
  range = [-range, range]
  ;
  ; Do the plotting....
  ;
  IF KEYWORD_SET(time) THEN $
    xtitle = 'TIME (hours)'  $
  ELSE  $
    xtitle = 'EDOP DWELL'
  PLOT, xcoord, vel1, XTITLE=xtitle, YTITLE='DOPPLER VELOCITY (m s!U-1!N)', $
        /XSTYLE, YRANGE=range, $
        TITLE='NASA EDOP   ' + UFstrtime(ufbuf) + ' ' + UFstrdate(ufbuf) + $
               ',  DGATE' + STRCOMPRESS(STRING(dgate))
  OPLOT, xcoord, vel2, LINESTYLE=5
END
