;
;==========================================================================
;
; FILE: ufstrstarttime.pro
;
; USAGE:  result = UFstrstarttime(ufbuf)
;         ARGUMENTS  ufbuf  Buffer of UF words for a radar dwell
;
; ABSTRACT: Return the volume start time as a formatted ASCII string
;           with the format hh:mm:ss ZZZ where ZZZ is a time zone
;           For EDOP the time may be used for the start of a flight leg
;
; AUTHOR:  I. Jeff Caylor
;          Science Systems and Applications, Inc.
;          5900 Princess Garden Parkway, Suite 300
;          Lanham, MD  20706
;
;     at:  NASA Goddard Space Flight Center
;          Code 912
;          Greenbelt, MD 20771
;          Voice: (301) 286-3767
;          Fax:   (301) 286-1762
;          Email: jeff.caylor@gsfc.nasa.gov
;
; CREATED: 7 April 1995
;
; MODIFIED:
;
;==========================================================================
;

;
; Return the volume start time in ASCII:  'hh:mm:ss ZZZ'
;
FUNCTION UFstrstarttime, dwell
  d = UFoptionalhdr(dwell)
  RETURN, STRING(FORMAT='(I2.2, ":", I2.2, ":", I2.2, A3, "T")', dwell(d+6), $
                 dwell(d+7), dwell(d+8), UFtimezone(dwell))
END
