;
;==========================================================================
;
; FILE: pitch_demo.pro
;
; USAGE:  pitch_demo, filename, /TIME
;         ARGUMENTS:  filename   Name of the UF disk file
;                     /TIME      Use time for x-axis, otherwise dwell number
;
; ABSTRACT:  Demonstration program to read an EDOP UF file and plot the pitch
;
; AUTHOR:  I. Jeff Caylor
;          Science Systems and Applications, Inc.
;          5900 Princess Garden Parkway, Suite 300
;          Lanham, MD  20706
;
;     at:  NASA Goddard Space Flight Center
;          Code 912
;          Greenbelt, MD 20771
;          Voice: (301) 286-3767
;          Fax:   (301) 286-1762
;          Email: jeff.caylor@gsfc.nasa.gov
;
; CREATED: 10 April 1995
;
; MODIFIED:
;
;==========================================================================
;
PRO pitch_demo, filename, TIME=time
  PRINT, 'Reading file: ', filename
  OPENR, infile, filename, /GET_LUN
;
  pitch = fltarr(1000)
  xcoord = fltarr(1000)
;
;
; Load data from disk
;
  i = 0
  WHILE (EOF(infile) NE 1)  DO  BEGIN
    UF_read_dwell, infile, ufbuf, /RDSS
    pitch(i) = UFedop_ins_pitch(ufbuf)
    IF keyword_set(time) THEN $
      xcoord(i) = UFtime(ufbuf)  $
    ELSE  $
      xcoord(i) = float(UFedop_dwell(ufbuf))
    print, 'Record: ', UFdwell(ufbuf), '  ', UFstrtime(ufbuf)
    i = i + 1
  ENDWHILE
  CLOSE, infile
  FREE_LUN, infile
;
; Resize arrays
;
  pitch = pitch(0 : i - 1)
  xcoord = xcoord(0 : i - 1)
;
; Do the plotting....
;
  IF keyword_set(time) THEN $
    xtitle = 'TIME (hours)'  $
  ELSE  $
    xtitle = 'EDOP DWELL'
  PLOT, xcoord, pitch, XTITLE=xtitle, YTITLE='PITCH (deg)', /XSTYLE, $
        TITLE='NASA EDOP    ' + UFstrdate(ufbuf)
END
