;
;==========================================================================
;
; FILE: calmode.pro
;
; USAGE: result = calmode(rstatus)
;        ARGUMENTS  rstatus  EDOP radar status register
;
; ABSTRACT: Return TRUE (1) if the radar is in calibration mode, otherwise
;           otherwise FALSE (0)
;
; AUTHOR:  I. Jeff Caylor
;          Science Systems and Applications, Inc.
;          5900 Princess Garden Parkway, Suite 300
;          Lanham, MD  20706
;
;     at:  NASA Goddard Space Flight Center
;          Code 912
;          Greenbelt, MD 20771
;          Voice: (301) 286-3767
;          Fax:   (301) 286-1762
;          Email: jeff.caylor@gsfc.nasa.gov
;
; CREATED: 5 January 1996
;
; MODIFIED:
;
;==========================================================================
;


;
; Examine the radar status word and determine if the radar is in
; internal calibration mode.  This mode is signaled by bits:
;   TX Low Power  ON
;   Radiate       ON
;   TWT HV off    OFF
;
; Return: 1 = calibration mode; 0 = _Not_ calibration mode
;
FUNCTION calmode, rstatus
  ;
  ;  TWTAST_MASK  0x0080  Hi = TWT high voltage off (TWTA status)
  ;  STDBY_MASK   0x0200  Hi = Radiate
  ;  TXLPOW_MASK  0x0400  Hi = Transmitter low power
  ;
  IF (rstatus AND '0400'X) NE 0  AND $
     (rstatus AND '0200'X) NE 0  AND $
     (rstatus AND '0080'X) EQ 0 THEN return, 1 ELSE return, 0
END
