;
;==========================================================================
;
; FILE: uf_surfref.pro
;
; USAGE: result = UF_surfref(ufbuf, name)
;        ARGUMENTS  ufbuf  Buffer of UF words for a dwell of radar data
;                   name   2 character ASCII name of the data field
;
; ABSTRACT: Return the reference reflectivity value used for in the 
;           SRT processing 
;
; AUTHOR:  I. Jeff Caylor
;          Science Systems and Applications, Inc.
;          5900 Princess Garden Parkway, Suite 300
;          Lanham, MD  20706
;
;     at:  NASA Goddard Space Flight Center
;          Code 912
;          Greenbelt, MD 20771
;          Voice: (301) 286-3767
;          Fax:   (301) 286-1762
;          Email: jeff.caylor@gsfc.nasa.gov
;
; CREATED: 3 January 1996
;
; MODIFIED:
;
;==========================================================================
;


;
; For the named field, return the surface reflectivity reference value
; Units are dBZ
; Error = -1
;
FUNCTION UF_surfref, dwell, name
  pia = -1
  ;
  ; Get the logical field number
  ;
  field = UFfieldnumber(dwell, name)
  ;
  ; If there is a word in the field specific area and the named field
  ; exists then convert the surface reflectivity
  ;
  IF (UFspword_size(dwell, field) GE 7  AND  field NE -1) THEN  $
    pia = FLOAT(dwell(UFspwords(dwell, field) + 6)) / UFdatascale(dwell, field)
;
  RETURN, pia
END
